==> qmmp-0.6.8.tar.bz2: qmmp-0.6.8/src/plugins/Input/aac/translations/aac_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<context>
    <name>AACMetaDataModel</name>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="43"/>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="45"/>
        <source>Sample rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="45"/>
        <source>Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="47"/>
        <source>Bitrate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="47"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="48"/>
        <source>KB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="49"/>
        <source>File size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DecoderAACFactory</name>
    <message>
        <location filename="../decoderaacfactory.cpp" line="46"/>
        <source>AAC Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="48"/>
        <source>AAC Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="88"/>
        <source>About AAC Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="89"/>
        <source>Qmmp AAC Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="90"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/Input/aac/translations/aac_plugin_pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>AACMetaDataModel</name>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="43"/>
        <source>Length</source>
        <translation>Długość</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="45"/>
        <source>Sample rate</source>
        <translation>Próbkowanie</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="45"/>
        <source>Hz</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="47"/>
        <source>Bitrate</source>
        <translation>Szybkość transmisji</translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="47"/>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="48"/>
        <source>KB</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../aacmetadatamodel.cpp" line="49"/>
        <source>File size</source>
        <translation>Wilekość pliku</translation>
    </message>
</context>
<context>
    <name>DecoderAACFactory</name>
    <message>
        <location filename="../decoderaacfactory.cpp" line="46"/>
        <source>AAC Plugin</source>
        <translation>Wtyczka AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="48"/>
        <source>AAC Files</source>
        <translation>Pliki AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="88"/>
        <source>About AAC Audio Plugin</source>
        <translation>O wtyczce dźwiękowej AAC</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="89"/>
        <source>Qmmp AAC Audio Plugin</source>
        <translation>Wtyczka AAC dla Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderaacfactory.cpp" line="90"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
